:github_url: https://github.com/stephane-caron/qpsolvers/tree/master/doc/src/references.rst

**********
References
**********

.. [tolprimer] `Optimality conditions and numerical tolerances in QP solvers <https://scaron.info/blog/optimality-conditions-and-numerical-tolerances-in-qp-solvers.html>`_, S. Caron, 2022.

.. [Bambade2022] `PROX-QP: Yet another Quadratic Programming Solver for Robotics and beyond <https://hal.inria.fr/hal-03683733/file/Yet_another_QP_solver_for_robotics_and_beyond.pdf/>`__, A. Bambade, S. El-Kazdadi, A. Taylor, J. Carpentier. Robotics: Science and Systems. 2022.

.. [Pandala2019] `qpSWIFT: A real-time sparse quadratic program solver for robotic applications <https://doi.org/10.1109/LRA.2019.2926664>`_, A. G. Pandala, Y. Ding, H. W. Park. IEEE Robotics and Automation Letters, 2019, vol. 4, no 4, p. 3355-3362.

.. [Vandenberghe2010] `The CVXOPT linear and quadratic cone program solvers <https://www.seas.ucla.edu/~vandenbe/publications/coneprog.pdf>`_, L. Vandenberghe. 2010.
